@@ -126,8 +126,10 @@ repos = OrderedDict({
     'pi': cms + [
         'cloudmesh-admin',
         'cloudmesh-inventory',
+        'cloudmesh-ssh',
         'cloudmesh-pi-cluster',
         'cloudmesh-pi-burn',
+        'cloudmesh-diagram',
     ],
 
     # 'cloudmesh-cloud',
